(get-bytes mmap pos n)(get-mmap filename)(get-mmap filename map-mode)Provided a filename, mmap the entire file, and return an opaque type to allow further access. Remember to use with-open, or to call .close, to clean up memory and open file descriptors.
Provided a filename, mmap the entire file, and return an opaque type to allow further access. Remember to use with-open, or to call .close, to clean up memory and open file descriptors.
(loaded? mmap)(put-bytes mmap buf pos)(put-bytes mmap buf pos n)Write n bytes from buf into mmap, at byte position pos. If n isn't provided, the size of the buffer provided is used.
Write n bytes from buf into mmap, at byte position pos. If n isn't provided, the size of the buffer provided is used.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |